@@ -33,6 +33,7 @@ from calibre.gui2.preferences.coloring import EditRules
 from calibre.gui2.library.alternate_views import auto_height, CM_TO_INCH
 from calibre.gui2.widgets2 import Dialog
 
+
 class BusyCursor(object):
 
     def __enter__(self):
@@ -43,6 +44,7 @@ class BusyCursor(object):
 
 # IdLinksEditor {{{
 
+
 class IdLinksRuleEdit(Dialog):
 
     def __init__(self, key='', name='', template='', parent=None):
@@ -83,6 +85,7 @@ class IdLinksRuleEdit(Dialog):
                     'The %s field cannot be empty') % which, show=True)
         Dialog.accept(self)
 
+
 class IdLinksEditor(Dialog):
 
     def __init__(self, parent=None):
@@ -150,6 +153,7 @@ class IdLinksEditor(Dialog):
             self.table.removeRow(r)
 # }}}
 
+
 class DisplayedFields(QAbstractListModel):  # {{{
 
     def __init__(self, db, parent=None):
@@ -224,6 +228,7 @@ class DisplayedFields(QAbstractListModel):  # {{{
 
 # }}}
 
+
 class Background(QWidget):  # {{{
 
     def __init__(self, parent):
@@ -257,6 +262,7 @@ class Background(QWidget):  # {{{
         painter.end()
 # }}}
 
+
 class ConfigWidget(ConfigWidgetBase, Ui_Form):
 
     size_calculated = pyqtSignal(object)
@@ -278,6 +284,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         r('ui_style', gprefs, restart_required=True, choices=[(_('System default'), 'system'), (_('Calibre style'),
                     'calibre')])
         r('book_list_tooltips', gprefs)
+        r('row_numbers_in_book_list', gprefs)
         r('tag_browser_old_look', gprefs, restart_required=True)
         r('tag_browser_hide_empty_categories', gprefs)
         r('bd_show_cover', gprefs)
@@ -638,13 +645,17 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         self.update_font_display()
         gui.tags_view.reread_collapse_parameters()
         gui.library_view.refresh_book_details()
+        gui.library_view.set_row_header_visibility()
         gui.cover_flow.setShowReflections(gprefs['cover_browser_reflections'])
         gui.cover_flow.setPreserveAspectRatio(gprefs['cb_preserve_aspect_ratio'])
         gui.update_cover_flow_subtitle_font()
         gui.cover_flow.template_inited = False
+        for view in 'library memory card_a card_b'.split():
+            getattr(gui, view + '_view').set_row_header_visibility()
         gui.library_view.refresh_row_sizing()
         gui.grid_view.refresh_settings()
 
+
 if __name__ == '__main__':
     from calibre.gui2 import Application
     app = Application([])
